(build-init-form {{:keys [init init-ns]} :repl-options :keys [global-vars]})(format-jvm-opts {:keys [jvm-opts compile-path]})(format-nrepl-options {:keys [transport nrepl-handler socket nrepl-middleware
host port]})(middleware project)(middleware* {:keys [repl-options java-source-paths] :as project})(remove-enrich-middleware mw)(remove-enrich-middleware-from-map m)(wrap-try init-ns init global-vars)Wraps init in a try/catch because otherwise clojure.main
can fail at startup, while 'init' errors can often be remediated by the user later.
Wraps `init` in a try/catch because otherwise `clojure.main` can fail at startup, while 'init' errors can often be remediated by the user later.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |